# October 10, 2023 - Version 1.2.4


## Summary

---

**🔗 Resample Improvement: Resample is now able to accept flexible values**

**✈️ Sign, Radians and Degrees functions are newly added!**

**⚡️ Conda pakcages are now available to use!**

Please update PrismStudio via

```python
pip install prismstudio --upgrade
```

or

```python
pip install prismstudio==1.2.4
```


If you prefer to use Anaconda, please install PrismStudio using command below

```bash
conda config --add channels conda-forge
conda install -c prism39 prismstudio
```

## October 10, 2023 -
PrismStudio 1.2.4

---

### Resample Improvement
Please find [Resample](<#prism._PrismComponent.resample>) for more details.


### Frequency
Frequency parameters in Screen, Factor Backtest can use dynamic values. Please find frequency parameter in [Screen](<#prism.screen>) and [Factor Backtest](<#prism.factor_backtest>)


### Sign, Radians, Degrees functions
[Sign](<#prism._PrismComponent.sign>), [Degrees](<#prism._PrismComponent.degrees>) and [Radians](<#prism._PrismComponent.radians>) functions are added.


### Factor Backtest
Factor Backtest bug has been fixed.


### Conda packages
Now PrismStudio can be downloaded from Prism39 conda channel.
Please install PrismStudio from conda channel using script below.
```bash
conda config --add channels conda-forge
conda install -c prism39 prismstudio
```
Our conda version of PrismStudio support following python versions:
- Python 3.8
- Python 3.9
- Python 3.10
- Python 3.11

And following OS and architectures:
- Windows x86
- Linux x86
- MacOSX arm


